package Locale::CLDR::Tig::Any v0.25.0;
# This file auto generated
#	on Tue 22 Apr 12:46:07 am GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Tig');

no Moose;
__PACKAGE__->meta->make_immutable;
